@@ -1,8 +1,10 @@
 mod args;
 mod dumper;
+mod writer;
 
 use clap::{load_yaml, App};
-use dumper::Dumper;
+
+use crate::dumper::Dumper;
 
 fn main() {
     let yaml = load_yaml!("args.yml");
@@ -14,19 +16,16 @@ fn main() {
 
     match options.kind.as_str() {
         "sqlite" => {
-            use dumper::sqlite;
-            let sqlite_dumper = sqlite::Sqlite;
-            sqlite_dumper.dump(&options);
+            let sqlite = dumper::sqlite::Sqlite;
+            sqlite.dump(&options);
         }
         "mysql" => {
-            use dumper::mysql;
-            let mysql_dumper = mysql::Mysql;
-            mysql_dumper.dump(&options);
+            let mysql = dumper::mysql::Mysql;
+            mysql.dump(&options);
         }
         "postgresql" => {
-            use dumper::postgresql;
-            let postgresql_dumper = postgresql::Postgresql;
-            postgresql_dumper.dump(&options);
+            let postgresql = dumper::postgresql::Postgresql;
+            postgresql.dump(&options);
         }
         _ => (),
     }
